<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/urls?lang_cible=ast
// ** ne pas modifier le fichier **

return [

	// T
	'texte_type_urls' => 'Embaxo pues escoyer el mou de cálculu de les señes de les páxines.',
	'texte_type_urls_attention' => 'Atención esti axuste nun funcionará más que si l’archivu @htaccess@ ta correutamente instaláu na raiz del sitiu.',
	'titre_type_urls' => 'Tipu de señes URL',
];
